@@ -41,7 +41,7 @@ def jprint(*args):
 
 # # Requiremtns
 
-# In[ ]:
+# In[5]:
 
 
 requirements = []
@@ -438,10 +438,14 @@ if isnotebook():
 
 
 
-# In[ ]:
+# # Shell
 
+# In[52]:
 
 
+def shell(cmd):
+    result = subprocess.run(cmd, shell=True, stdout=subprocess.PIPE)
+    return result.stdout.decode()
 
 
 # # Package Files
@@ -520,40 +524,26 @@ SOFTWARE."""
 package_files['README.md'] = ""
 
 
-# In[46]:
-
-
-get_ipython().system(' jupyter nbconvert --to script lx.ipynb')
-
-
 # In[47]:
 
 
-package_files['lx/__init__.py'] = txtread("lx.py")
+if isnotebook():
+    get_ipython().system(' jupyter nbconvert --to script lx.ipynb')
+    package_files['lx/__init__.py'] = txtread("lx.py")
 
 
-# In[48]:
-
-
-def shell(cmd):
-    result = subprocess.run(cmd, shell=True, stdout=subprocess.PIPE)
-    return result.stdout.decode()
-
-
-# In[50]:
+# In[51]:
 
 
 if isnotebook():
-    #with tempfile.TemporaryDirectory() as d:
-    d = "/tmp/asdf9e2"
-    os.makedirs(d)
-    for key, value in package_files.items():
-        txtwrite(os.path.join(d, key), value)
+    with tempfile.TemporaryDirectory() as d:
+        for key, value in package_files.items():
+            txtwrite(os.path.join(d, key), value)
 
-    print("\n".join(fiFindByWildcard(os.path.join(d, '**/*'))))
+        print("\n".join(fiFindByWildcard(os.path.join(d, '**/*'))))
 
-    #print(shell("cd {d} && git status && git config user.name 'lx' && git config user.email 'lx' && git commit -a -m 'Add' && git log && git push && python setup.py sdist && twine upload dist/* --verbose".format(d=d)))
-    print(shell("cd {d} && python3 setup.py sdist && twine upload dist/* --verbose".format(d=d)))
+        #print(shell("cd {d} && git status && git config user.name 'lx' && git config user.email 'lx' && git commit -a -m 'Add' && git log && git push && python setup.py sdist && twine upload dist/* --verbose".format(d=d)))
+        print(shell("cd {d} && python3 setup.py sdist && twine upload dist/* --verbose".format(d=d)))
 
 
 # In[ ]:
